Module array

Module array 

Lazy implemntation of the array trait and associated functionality

Enums

Array
Wrapper around the tape that allows interacting with it via a Array-like API.
Iter
Iterator over the values in an array