Enum simd_json::value::tape::Node [−][src]
pub enum Node<'input> {
String(&'input str),
Object(usize, usize),
Array(usize, usize),
Static(StaticNode),
}Expand description
Tape Node
Variants
String(&'input str)A string, located inside the input slice
An Object with the given size starts here.
the following values are keys and values, alternating
however values can be nested and have a length themselves.
An array with a given size starts here. The next size
elements belong to it - values can be nested and have a
size of their own.
Static(StaticNode)A static value that is interned into the tape, it can be directly taken and isn’t nested.